<?php

App::uses('Image', 'EvCore.Model');

class VariantImage extends Image {

	public $useTable = 'images'; // Don't set a table prefix here

	public $alias = 'VariantImage'; // The following two options should match

	public $name = 'VariantImage';

	public $hasMany = [
		'VariantImageOption' => [
			'className' => 'EvShop.VariantImageOption'
		]
	];

	public function afterFind($results, $primary = false) {
		$results = parent::afterFind($results, $primary);

		//Find variant image options if it has any (is_restricted = true) and add them to the results
		//Surely there has to be a better way - http://i.imgur.com/GT7yitp.gif
		foreach ($results as $resultKey => $variantImage) {
			foreach ($variantImage as $imageType => $image) {
				//Only get the options if the image is restricted to a variant.
				// if (isset($image['is_restricted']) && $image['is_restricted']) {
					$imageId = $image['id'];

					$imageOptions = $this->VariantImageOption->find('all', [
						'conditions' => [
							'VariantImageOption.image_id' => $imageId
						]
					]);

					if (!empty($imageOptions)) {
						foreach ($imageOptions as $imageOption) {
							$results[$resultKey][$imageType]['VariantImageOption'][] = $imageOption['VariantImageOption'];
						}

					}
				// }
			}
		}

		return $results;
	}

	public function processVariantImages($data, $imageSlots) {
		foreach ($imageSlots as $slotName => $slotInfo) {
			$arrayIndex = ucfirst($slotName) . 'VariantImage';
			if (isset($data[$arrayIndex])) {
				$variantImages = $data[$arrayIndex];
				foreach ($variantImages as $imageKey => $image) {
					if (isset($image['is_restricted']) && $image['is_restricted']) {
						//Remove any options that have don't have option_id set
						foreach ($image['VariantImageOption'] as $optionKey => $option) {
							if (!isset($option['option_id']) && empty($option['id'])) {
								//If an option hasn't been selected and it has yet to be added then remove it so it isn't
								//Otherwise it already has a record and needs to be removed
								unset($data[$arrayIndex][$imageKey]['VariantImageOption'][$optionKey]);
							}
						}
					} else {
						if (isset($image['VariantImageOption'])) {
							unset($data[$arrayIndex][$imageKey]['VariantImageOption']);
						}
					}
				}
			}
		}

		return $data;
	}

	public function removeDeletedOptions($data, $imageSlots) {
		$deletedOptions = [];

		foreach ($imageSlots as $slotName => $slotInfo) {
			$arrayIndex = ucfirst($slotName) . 'VariantImage';
			if (isset($data[$arrayIndex])) {
				$variantImages = $data[$arrayIndex];
				foreach ($variantImages as $imageKey => $image) {
					if (isset($image['VariantImageOption']) && !empty($image['VariantImageOption'])) {
						foreach ($image['VariantImageOption'] as $imageOptionKey => $imageOption) {
							if (!empty($imageOption['id']) && !isset($imageOption['option_id'])) {
								$deletedOptions[] = $imageOption['id'];
								unset($data[$arrayIndex][$imageKey]['VariantImageOption'][$imageOptionKey]);
							}
						}
					}
				}
			}
		}

		$VariantImageOption = EvClassRegistry::init('EvShop.VariantImageOption');
		$VariantImageOption->deleteAll(
			[
				'VariantImageOption.id' => $deletedOptions
			]
		);

		return $data;
	}
}
